ProSHADE: Namespace Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

### - a -

- addAxisUnlessSame() : ProSHADE_internal_symmetry
- addExtraBoundSpace() : ProSHADE_internal_mapManip
- addToDblPtrVector() : ProSHADE_internal_misc
- addToDoubleVector() : ProSHADE_internal_misc
- addToDoubleVectorVector() : ProSHADE_internal_misc
- addToSignedVector() : ProSHADE_internal_misc
- addToSigPtrVector() : ProSHADE_internal_misc
- addToSingleVector() : ProSHADE_internal_misc
- addToStringVector() : ProSHADE_internal_misc
- addToUnsignVector() : ProSHADE_internal_misc
- addToUnsignVectorVector() : ProSHADE_internal_misc
- addZeroPeakToGroups() : ProSHADE_internal_symmetry
- advanceGLPolyValue() : ProSHADE_internal_maths
- allocateComputationMemory() : ProSHADE_internal_sphericalHarmonics
- allocateInvSOFTWorkspaces() : ProSHADE_internal_distances
- allocatePeakOptimisationMemory() : ProSHADE_internal_peakSearch
- allocateResolutionFourierMemory() : ProSHADE_internal_mapManip
- allocateSmoothingZScoreMemory() : ProSHADE_internal_peakSearch
- allocateTranslationFunctionMemory() : ProSHADE_internal_overlay
- allocateTrSigmaWorkspace() : ProSHADE_internal_distances
- allocateWignerWorkspace() : ProSHADE_internal_wigner
- applyCondonShortleyPhase() : ProSHADE_internal_sphericalHarmonics
- arrayMedianAndIQR() : ProSHADE_internal_maths
- autoDetermineBandwidth() : ProSHADE_internal_spheres
- autoDetermineIntegrationOrder() : ProSHADE_internal_spheres
- autoDetermineSphereDistances() : ProSHADE_internal_spheres